==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/src/Uncertainty/Algorithm/Experiments/Composite.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  Composite.cxx
 *  @brief Implementation of the composite experiment plane
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-10-31 11:52:04 +0100 (ven 31 oct 2008) $
 *  Id:      $Id: Composite.cxx 995 2008-10-31 10:52:04Z dutka $
 */
#include "Factorial.hxx"
#include "Axial.hxx"
#include "Composite.hxx"
#include <cmath>

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {

      CLASSNAMEINIT(Composite);

      /* Default constructor */
      Composite::Composite(const String & name):
	ExperimentImplementation(name)
      {
	// Nothing to do
      }

      /* Constructor with parameters */
      Composite::Composite(const NumericalPoint & center,
			   const NumericalPoint & levels,
			   const String & name):
	ExperimentImplementation(center, levels, name)
      {
	// Nothing to do
      }

      /* Constructor with parameters */
      Composite::Composite(const UnsignedLong dimension,
			   const NumericalPoint & levels,
			   const String & name):
	ExperimentImplementation(NumericalPoint(dimension, 0.0), levels, name)
      {
	// Nothing to do
      }

      /* Virtual constructor */
      Composite * Composite::clone() const
      {
	return new Composite(*this);
      }

      /* Experiment plane generation */
      Composite::NumericalSample Composite::generate()
      {
	/* Center of the experiment plane */
	NumericalPoint center(getCenter());
	/* Dimension of the realizations */
	UnsignedLong dimension(center.getDimension());
	/* Hypercube number of vertices */
	UnsignedLong verticesNumber((UnsignedLong)round(pow(2, dimension)));
	/* Levels */
	NumericalPoint levels(getLevels());
	/* Number of levels to be generated */
	UnsignedLong levelNumber(levels.getDimension());
	/* Size of the sample to be generated: 1 + number of levels x (2 x dimension + 2^dimension) */
	UnsignedLong size(1 + levelNumber * (2 * dimension + verticesNumber));
	/* A composite plane is made of an axial plane and a factorial plane with the same levels */
	/* First the axial plane */
	Axial axial(getCenter(), levels);
	NumericalSample axialPlane(axial.generate());
	/* Second the factorial plane */
	Factorial factorial(getCenter(), levels);
	NumericalSample factorialPlane(factorial.generate());
	/* We create the composite plane by copying the factorial plane (larger than the axial plane) then we append all the elements of the axial plane excepted its first one, which is the center of the plane and thus already present in the factorial plane */
	NumericalSample compositePlane(size, center);
	compositePlane.setName("Composite plane");
	UnsignedLong index(0);
	size = factorialPlane.getSize();
	for(UnsignedLong factorialIndex = 0; factorialIndex < size; factorialIndex++)
	  {
	    compositePlane[index] = factorialPlane[factorialIndex];
	    index++;
	  }
	size = axialPlane.getSize();
	for(UnsignedLong axialIndex = 1; axialIndex < size; axialIndex++)
	  {
	    compositePlane[index] = axialPlane[axialIndex];
	    index++;
	  }
	return compositePlane;
      } // generate()

      /* String converter */
      String Composite::str() const
      {
	OSS oss;
	oss << "class=" << GetClassName()
	    << " name=" << getName()
	    << " center=" << getCenter()
	    << " levels=" << getLevels();
	return oss;
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

==> openturns_0.13.2.orig.tar.gz: openturns-0.13.2/lib/src/Uncertainty/Algorithm/Experiments/Composite.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  Composite.cxx
 *  @brief Implementation of the composite experiment plane
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: Composite.cxx 1473 2010-02-04 15:44:49Z dutka $
 */
#include "Factorial.hxx"
#include "Axial.hxx"
#include "Composite.hxx"
#include <cmath>

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {

      CLASSNAMEINIT(Composite);

      /* Default constructor */
      Composite::Composite(const String & name):
	StratifiedExperiment(name)
      {
	// Nothing to do
      }

      /* Constructor with parameters */
      Composite::Composite(const NumericalPoint & center,
			   const NumericalPoint & levels,
			   const String & name):
	StratifiedExperiment(center, levels, name)
      {
	// Nothing to do
      }

      /* Constructor with parameters */
      Composite::Composite(const UnsignedLong dimension,
			   const NumericalPoint & levels,
			   const String & name):
	StratifiedExperiment(NumericalPoint(dimension, 0.0), levels, name)
      {
	// Nothing to do
      }

      /* Virtual constructor */
      Composite * Composite::clone() const
      {
	return new Composite(*this);
      }

      /* Experiment plane generation */
      Composite::NumericalSample Composite::generate()
      {
	/* Dimension of the realizations */
	UnsignedLong dimension(center_.getDimension());
	/* Hypercube number of vertices */
	UnsignedLong verticesNumber((UnsignedLong)round(pow(2, dimension)));
	/* Number of levels to be generated */
	UnsignedLong levelNumber(levels_.getDimension());
	/* Size of the sample to be generated: 1 + number of levels x (2 x dimension + 2^dimension) */
	UnsignedLong size(1 + levelNumber * (2 * dimension + verticesNumber));
	/* A composite plane is made of an axial plane and a factorial plane with the same levels */
	/* First the axial plane */
	Axial axial(center_, levels_);
	NumericalSample axialPlane(axial.generate());
	/* Second the factorial plane */
	Factorial factorial(center_, levels_);
	NumericalSample factorialPlane(factorial.generate());
	/* We create the composite plane by copying the factorial plane (larger than the axial plane) then we append all the elements of the axial plane excepted its first one, which is the center of the plane and thus already present in the factorial plane */
	NumericalSample compositePlane(size, center_);
	compositePlane.setName("Composite plane");
	UnsignedLong index(0);
	size = factorialPlane.getSize();
	for(UnsignedLong factorialIndex = 0; factorialIndex < size; factorialIndex++)
	  {
	    compositePlane[index] = factorialPlane[factorialIndex];
	    index++;
	  }
	size = axialPlane.getSize();
	for(UnsignedLong axialIndex = 1; axialIndex < size; axialIndex++)
	  {
	    compositePlane[index] = axialPlane[axialIndex];
	    index++;
	  }
	return compositePlane;
      } // generate()

      /* String converter */
      String Composite::__repr__() const
      {
	OSS oss;
	oss << "class=" << GetClassName()
	    << " name=" << getName()
	    << " center=" << center_
	    << " levels=" << levels_;
	return oss;
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
